@@ -478,10 +478,10 @@ class TestCommissionType:
         res = dict()
         for commission_type in CommissionType.objects.all():
             for (
-                terminal_account,
-                compute_date,
-                commission,
-                product,
+                _,
+                _,
+                _,
+                _,
                 recipient,
                 recipient_fees,
                 _,
